@@ -181,6 +181,11 @@ sub header {
         $str .= "#SBATCH --mail-user=" . $self->{email_address} . "\n";
         $str .= "#SBATCH --mail-type=" . $self->{email_type} . "\n";
     }
+    # Custom options
+    for my $o (@{$self->{opts}}) {
+        next if not defined $o;
+        $str .= "#SBATCH $o\n";
+    }
     return $str;
 }
 
@@ -267,7 +272,7 @@ NBI::Opts - A class for representing a the SLURM options for NBI::Slurm
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 SYNOPSIS
 
