@@ -26,7 +26,7 @@ sub new {
     my $state_short;
     my $partitions_csv;
     my $jobname;
-    if (substr($_[0], 0, 1) eq '-') {
+    if (defined $_[0] and substr($_[0], 0, 1) eq '-') {
         my %data = @_;
         for my $i (keys %data) {
             if ($i =~ /^-user/)  {
@@ -160,7 +160,7 @@ NBI::Queue - NBI::Queue, to filter jobs in the queue
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 SYNOPSIS
 
